# runtime.resilience

## Purpose
Domain runtime primitives for resilience.

## Owns
- Modules under `vyro.runtime.resilience`.

## Entry Points
- `vyro.runtime.resilience`

## Not Here
- Public app composition (`vyro.app`).
